@@ -48,8 +48,8 @@ REFERENCES = [UK_WHO, TRISOMY_21, TURNERS]
 SEXES = [MALE, FEMALE]
 MEASUREMENT_METHODS = [HEIGHT, WEIGHT, HEAD_CIRCUMFERENCE, BMI]
 
-THREE_PERCENT_CENTILES = 'six-centiles'
-COLE_TWO_THIRDS_SDS_NINE_CENTILES = 'nine-centiles'
+THREE_PERCENT_CENTILES = 'three-percent-centiles'
+COLE_TWO_THIRDS_SDS_NINE_CENTILES = 'cole-nine-centiles'
 CENTILE_FORMATS=[THREE_PERCENT_CENTILES, COLE_TWO_THIRDS_SDS_NINE_CENTILES]
 
 THREE_PERCENT_CENTILE_COLLECTION = [
