@@ -112,7 +112,10 @@ class Measurement:
                 "y": self.observation_value,
                 "b": self.bone_age,
                 "events_text": self.events_text,
-                "bone_age_label": bone_age_comment,
+                "bone_age_label": self.bone_age_text,
+                "bone_age_type": self.bone_age_type,
+                "bone_age_sds": self.bone_age_sds,
+                "bone_age_centile": self.bone_age_centile,
                 "observation_error": self.calculated_measurements_object['child_observation_value']["observation_value_error"],
                 "age_type": "chronological_age",
                 "calendar_age": self.ages_object["measurement_dates"]["chronological_calendar_age"],
@@ -128,7 +131,10 @@ class Measurement:
                 "y": self.observation_value,
                 "b": self.bone_age,
                 "events_text": self.events_text,
-                "bone_age_label": f"SDS: {self.bone_age_sds}, Centile: {self.bone_age_type}",
+                "bone_age_label": self.bone_age_text,
+                "bone_age_type": self.bone_age_type,
+                "bone_age_sds": self.bone_age_sds,
+                "bone_age_centile": self.bone_age_centile,
                 "observation_error": self.calculated_measurements_object['child_observation_value']["observation_value_error"],
                 "age_type": "corrected_age",
                 "corrected_gestational_age": corrected_gestational_age,
@@ -146,7 +152,11 @@ class Measurement:
                 "x": self.ages_object['measurement_dates']['chronological_decimal_age'],
                 "y": self.calculated_measurements_object['measurement_calculated_values']["chronological_sds"],
                 "b": self.bone_age,
-                "bone_age_label": f"SDS: {self.bone_age_sds}, Centile: {self.bone_age_type}",
+                "events_text": self.events_text,
+                "bone_age_label": self.bone_age_text,
+                "bone_age_type": self.bone_age_type,
+                "bone_age_sds": self.bone_age_sds,
+                "bone_age_centile": self.bone_age_centile,
                 "age_type": "chronological_age",
                 "calendar_age": self.ages_object["measurement_dates"]["chronological_calendar_age"],
                 "lay_comment": self.ages_object["measurement_dates"]["comments"]["lay_chronological_decimal_age_comment"],
@@ -159,7 +169,11 @@ class Measurement:
                 "x": self.ages_object['measurement_dates']['corrected_decimal_age'],
                 "y": self.calculated_measurements_object['measurement_calculated_values']["corrected_sds"],
                 "b": self.bone_age,
-                "bone_age_label": f"SDS: {self.bone_age_sds}, Centile: {self.bone_age_type}",
+                "events_text": self.events_text,
+                "bone_age_label": self.bone_age_text,
+                "bone_age_type": self.bone_age_type,
+                "bone_age_sds": self.bone_age_sds,
+                "bone_age_centile": self.bone_age_centile,
                 "age_type": "corrected_age",
                 "corrected_gestational_age": corrected_gestational_age,
                 "calendar_age": self.ages_object["measurement_dates"]["corrected_calendar_age"],
